
import javafx.application.Application;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.stage.Stage;

/**
 * A button with an embedded image.
 *
 * @sampleName Graphic Button
 * @preview preview.png
 * @docUrl http://www.oracle.com/pls/topic/lookup?ctx=javase80&id=JFXUI336 Using JavaFX UI Controls
 * @see javafx.scene.control.Button
 * @see javafx.scene.image.ImageView
 * @embedded
 *
 * @related /Controls/Button/Colored Buttons
 * @related /Controls/Button/Pill Button
*/
public class GraphicButtonApp extends Application {

    public Parent createContent() {
        final String URL = "icon-48x48.png";
        final Image ICON_48 = new Image(getClass().getResourceAsStream(URL));
        final ImageView imageView = new ImageView(ICON_48);
        final Button button = new Button("Press", imageView);

        return button;
    }

    @Override public void start(Stage primaryStage) throws Exception {
        primaryStage.setScene(new Scene(createContent()));
        primaryStage.show();
    }

    /** Java main for when running without JavaFX launcher
     * @param args command line arguments
     */
    public static void main(String[] args) {
        launch(args);
    }
}
