import javafx.application.Application;
import javafx.event.Event;
import javafx.event.EventHandler;
import javafx.event.ActionEvent;
import javafx.geometry.Pos;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.ColorPicker;
import javafx.scene.control.Label;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import javafx.stage.Stage;

/**
 * A sample that demonstrates the ColorPicker.
 *
 * @sampleName ColorPicker
 * @preview preview.png
 * @docUrl http://www.oracle.com/pls/topic/lookup?ctx=javase80&id=JFXUI336 Using JavaFX UI Controls
 * @see javafx.scene.control.Button
 * @see javafx.scene.control.ColorPicker
 * @see javafx.scene.control.Label
 *
 * @related /Controls/DatePicker
 */
public class ColorPickerApp extends Application {

    public Parent createContent() {
        final ColorPicker colorPicker = new ColorPicker(Color.GREEN);
        final Label coloredText = new Label("Colors");
        coloredText.setFont(new Font(53));
        final Button coloredButton = new Button("Colored Control");
        Color c = colorPicker.getValue();
        coloredText.setTextFill(c);
        coloredButton.setStyle(createRGBString(c));

        colorPicker.setOnAction(new EventHandler<ActionEvent>() {
            @Override public void handle(ActionEvent t) {
                Color newColor = colorPicker.getValue();
                coloredText.setTextFill(newColor);
                coloredButton.setStyle(createRGBString(newColor));
            }
        });

        VBox outerVBox = new VBox(coloredText, coloredButton, colorPicker);
        outerVBox.setAlignment(Pos.CENTER);
        outerVBox.setSpacing(20);
        outerVBox.setMaxSize(VBox.USE_PREF_SIZE, VBox.USE_PREF_SIZE);

        return outerVBox;
    }

    private String createRGBString(Color c) {
        return String.format("-fx-base: rgb(%f,%f,%f);", (c.getRed() * 255),
                             (c.getGreen() * 255), (c.getBlue() * 255));
    }

    @Override
    public void start(Stage primaryStage) throws Exception {
        primaryStage.setScene(new Scene(createContent()));
        primaryStage.show();
    }

    /**
     * Java main for when running without JavaFX launcher
     * @param args command line arguments
     */
    public static void main(String[] args) {
        launch(args);
    }
}
